/* This file is part of the KDE project
   Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
   Copyright (C) 2004  Alexander Dymo <cloudtemple@mskat.net>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPROPERTY_SIZEPOLICYEDIT_H
#define KPROPERTY_SIZEPOLICYEDIT_H

#include "../widget.h"

#include <tqvariant.h>

template<class U, class T> class TQMap;

class TQLabel;

namespace KoProperty {

class KOPROPERTY_EXPORT SizePolicyEdit : public Widget
{
	Q_OBJECT
  

	public:
		SizePolicyEdit(Property *property, TQWidget *parent=0, const char *name=0);
		virtual ~SizePolicyEdit();

		virtual TQVariant value() const;
		virtual void setValue(const TQVariant &value, bool emitChange=true);

		virtual void drawViewer(TQPainter *p, const TQColorGroup &cg, const TQRect &r, const TQVariant &value);

	protected:
		virtual void setReadOnlyInternal(bool readOnly);
		TQString findDescription(const TQVariant &value) const;

	private:
		TQVariant  m_value;
		TQLabel  *m_edit;
		static TQStringVariantMap *m_spValues;
};

}

#endif
